@@ -1,9 +1,10 @@
 from requests import Response
 from .LoginStepHandler import LoginStepHandler
+from .OnlineChecker import OnlineChecker
 
 
 class LoginFinalizeHandler(LoginStepHandler):
     def next_step(self, accumulated, last_response: Response) -> ({}, Response):
         del accumulated["login_barcode"]
         del accumulated["login_success_url"]
-        return accumulated, last_response
+        return accumulated, OnlineChecker.check_online(accumulated, self.session)
