@@ -84,13 +84,13 @@ class SmartqqClient:
 
     def message_preprocess(self, data):
         message = data.json()
-        logger.info(str(message))
         if ("retcode" in message) and message["retcode"] != 0:
             if message["retcode"] == 103:
                 logger.info(OnlineChecker.check_online(self.login_data, self.session).content)
             raise MessageErrcodeException
         if "result" not in message:
             raise MessageErrcodeException
+        logger.info(str(message["result"][0]))
         return message["result"][0]
 
     def __init__(self, login_data=None, barcode_handler=None,
